==> jc-1.4.0.tar.gz: soot/grimp/internal/GSpecialInvokeExpr.h <==
// public class soot.grimp.internal.GSpecialInvokeExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7a6f7c3fdc5dcff1 soot_grimp_internal_GSpecialInvokeExpr
// @dep_class a0ee2217a7b698d3 soot_jimple_internal_AbstractInstanceInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class c1e420bc363ef3b0 soot_jimple_internal_AbstractSpecialInvokeExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractSpecialInvokeExpr

#include "soot/jimple/internal/AbstractSpecialInvokeExpr.h"

#ifndef _JC_soot_grimp_internal_GSpecialInvokeExpr_H_
#define _JC_soot_grimp_internal_GSpecialInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GSpecialInvokeExpr$sub_refs	_jc_soot_grimp_internal_GSpecialInvokeExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GSpecialInvokeExpr$sub_nonrefs	_jc_soot_grimp_internal_GSpecialInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GSpecialInvokeExpr$refs	_jc_soot_grimp_internal_GSpecialInvokeExpr$refs;
typedef struct _jc_soot_grimp_internal_GSpecialInvokeExpr$nonrefs	_jc_soot_grimp_internal_GSpecialInvokeExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object	_jc_soot_grimp_internal_GSpecialInvokeExpr$object;

typedef const struct _jc_soot_grimp_internal_GSpecialInvokeExpr$vmethods	_jc_soot_grimp_internal_GSpecialInvokeExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GSpecialInvokeExpr$vtable	_jc_soot_grimp_internal_GSpecialInvokeExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GSpecialInvokeExpr$vtype	_jc_soot_grimp_internal_GSpecialInvokeExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GSpecialInvokeExpr$method$_init$737b9105a0ba7cab(_jc_env *, struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GSpecialInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object *);
extern jint _jc_soot_grimp_internal_GSpecialInvokeExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GSpecialInvokeExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object *);
extern void _jc_soot_grimp_internal_GSpecialInvokeExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GSpecialInvokeExpr$method$toString$dff3eb3766ed852d(_jc_env *, struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GSpecialInvokeExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_grimp_internal_GSpecialInvokeExpr$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_grimp_internal_GSpecialInvokeExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_grimp_internal_GSpecialInvokeExpr$method_info$toString$49ce0d4a4e59c2a6;
extern _jc_method _jc_soot_grimp_internal_GSpecialInvokeExpr$method_info$toString$dff3eb3766ed852d;

// Virtual methods structure
struct _jc_soot_grimp_internal_GSpecialInvokeExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object *);
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*toString$dff3eb3766ed852d)(_jc_env *, struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_soot_grimp_internal_GSpecialInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods	soot_jimple_internal_AbstractInstanceInvokeExpr;
	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vmethods	soot_jimple_internal_AbstractSpecialInvokeExpr;
	_jc_soot_grimp_internal_GSpecialInvokeExpr$vmethods	soot_grimp_internal_GSpecialInvokeExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GSpecialInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GSpecialInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GSpecialInvokeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GSpecialInvokeExpr$refs {
    _jc_soot_grimp_internal_GSpecialInvokeExpr$sub_refs	soot_grimp_internal_GSpecialInvokeExpr;
    _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_refs	soot_jimple_internal_AbstractSpecialInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GSpecialInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GSpecialInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractSpecialInvokeExpr;
    _jc_soot_grimp_internal_GSpecialInvokeExpr$sub_nonrefs	soot_grimp_internal_GSpecialInvokeExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object {
	_jc_soot_grimp_internal_GSpecialInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GSpecialInvokeExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GSpecialInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GSpecialInvokeExpr$vtype _jc_soot_grimp_internal_GSpecialInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GSpecialInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GSpecialInvokeExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GSpecialInvokeExpr_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/GSpecialInvokeExpr.h <==
// public class soot.grimp.internal.GSpecialInvokeExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7a6f7c3fdc5dcff1 soot_grimp_internal_GSpecialInvokeExpr
// @dep_class a0ee2217a7b698d3 soot_jimple_internal_AbstractInstanceInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class c1e420bc363ef3b0 soot_jimple_internal_AbstractSpecialInvokeExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractSpecialInvokeExpr

#include "soot/jimple/internal/AbstractSpecialInvokeExpr.h"

#ifndef _JC_soot_grimp_internal_GSpecialInvokeExpr_H_
#define _JC_soot_grimp_internal_GSpecialInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GSpecialInvokeExpr$sub_refs	_jc_soot_grimp_internal_GSpecialInvokeExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GSpecialInvokeExpr$sub_nonrefs	_jc_soot_grimp_internal_GSpecialInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GSpecialInvokeExpr$refs	_jc_soot_grimp_internal_GSpecialInvokeExpr$refs;
typedef struct _jc_soot_grimp_internal_GSpecialInvokeExpr$nonrefs	_jc_soot_grimp_internal_GSpecialInvokeExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object	_jc_soot_grimp_internal_GSpecialInvokeExpr$object;

typedef const struct _jc_soot_grimp_internal_GSpecialInvokeExpr$vmethods	_jc_soot_grimp_internal_GSpecialInvokeExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GSpecialInvokeExpr$vtable	_jc_soot_grimp_internal_GSpecialInvokeExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GSpecialInvokeExpr$vtype	_jc_soot_grimp_internal_GSpecialInvokeExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GSpecialInvokeExpr$method$_init$737b9105a0ba7cab(_jc_env *, struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GSpecialInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_grimp_internal_GSpecialInvokeExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GSpecialInvokeExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object *) _JC_JCNI_ATTR;
extern void _jc_soot_grimp_internal_GSpecialInvokeExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GSpecialInvokeExpr$method$toString$dff3eb3766ed852d(_jc_env *, struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GSpecialInvokeExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_grimp_internal_GSpecialInvokeExpr$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_grimp_internal_GSpecialInvokeExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_grimp_internal_GSpecialInvokeExpr$method_info$toString$49ce0d4a4e59c2a6;
extern _jc_method _jc_soot_grimp_internal_GSpecialInvokeExpr$method_info$toString$dff3eb3766ed852d;

// Virtual methods structure
struct _jc_soot_grimp_internal_GSpecialInvokeExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object *) _JC_JCNI_ATTR;
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$dff3eb3766ed852d)(_jc_env *, struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_GSpecialInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods	soot_jimple_internal_AbstractInstanceInvokeExpr;
	_jc_soot_jimple_internal_AbstractSpecialInvokeExpr$vmethods	soot_jimple_internal_AbstractSpecialInvokeExpr;
	_jc_soot_grimp_internal_GSpecialInvokeExpr$vmethods	soot_grimp_internal_GSpecialInvokeExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GSpecialInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GSpecialInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GSpecialInvokeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GSpecialInvokeExpr$refs {
    _jc_soot_grimp_internal_GSpecialInvokeExpr$sub_refs	soot_grimp_internal_GSpecialInvokeExpr;
    _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_refs	soot_jimple_internal_AbstractSpecialInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GSpecialInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GSpecialInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractSpecialInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractSpecialInvokeExpr;
    _jc_soot_grimp_internal_GSpecialInvokeExpr$sub_nonrefs	soot_grimp_internal_GSpecialInvokeExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GSpecialInvokeExpr$object {
	_jc_soot_grimp_internal_GSpecialInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GSpecialInvokeExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GSpecialInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GSpecialInvokeExpr$vtype _jc_soot_grimp_internal_GSpecialInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GSpecialInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GSpecialInvokeExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GSpecialInvokeExpr_H_ */
